;-----------------------------------------------------------------
;
; Name:		RobotDef.inc
; Title:	Defines for robot I/O, etc.
; Version:	1.0
; Last updated:	2001.03.10
; Target:	AT90S2313
;
;-----------------------------------------------------------------
;
; DESCRIPTION
;
; Defines for robot I/O
;
; Bit numbers begin with b
; Bitmasks begin with m
; Registers begin with r
; Other values are all uppercase
;
;-----------------------------------------------------------------

.include "2313def.inc"

;-----------------------------------------------------------------
;
; Robot specific port designations.
;
;-----------------------------------------------------------------
;
; Port D
;
; UART on pins D0, D1

; Bit #s
.equ	bBUMPF		=PIND2
.equ	bBUMPB		=PIND3
.equ	bEYEDRIVEL	=PIND4
.equ	bEYEDRIVER	=PIND5
.equ	bEYEDRIVEB	=PIND6

; Mask values
.equ	mBUMPF		=(1<<bBUMPF)
.equ	mBUMPB		=(1<<bBUMPB)
.equ	mEYEDRIVEL	=(1<<bEYEDRIVEL)
.equ	mEYEDRIVER	=(1<<bEYEDRIVER)
.equ	mEYEDRIVEB	=(1<<bEYEDRIVEB)

.equ	mBUMPS		=(mBUMPF|mBUMPB)
.equ	mEYEDRIVES	=(mEYEDRIVEL|mEYEDRIVER|mEYEDRIVEB)

.equ	mDDRD		=mEYEDRIVES

;-----------------------------------------------------------------
;
; Port B
;
; Analog comparator on B0, B1

; Bit #s
.equ	bRCREAD		=PINB0
.equ	bANALOGIN	=PINB1
.equ	bRCDRIVE	=PINB2
.equ	bIREDDRIVE	=PINB3
.equ	bMOTORLB	=PINB4
.equ	bMOTORLA	=PINB5
.equ	bMOTORRA	=PINB6
.equ	bMOTORRB	=PINB7

; Mask values
.equ	mRCREAD		=(1<<bRCREAD)
.equ	mANALOGIN	=(1<<bANALOGIN)
.equ	mRCDRIVE	=(1<<bRCDRIVE)
.equ	mIREDDRIVE	=(1<<bIREDDRIVE)
.equ	mMOTORLA	=(1<<bMOTORLA)
.equ	mMOTORLB	=(1<<bMOTORLB)
.equ	mMOTORRB	=(1<<bMOTORRB)
.equ	mMOTORRA	=(1<<bMOTORRA)

.equ	mMOTORS		=(mMOTORLA|mMOTORLB|mMOTORRA|mMOTORRB)

.equ	mDDRBREAD	=(mRCDRIVE|mIREDDRIVE|mMOTORS)
.equ	mDDRDISCHARGE	=(mDDRBREAD|mRCREAD)

;-----------------------------------------------------------------
;
; General purpose registers

.def	rRETURN		=r0	; return value from functions

.def	rSCRATCH	=r7
.def	rSCRATCH2	=r8
.def	rSCRATCH3	=r9
.def	rSCRATCH4	=r10

.def	rISCRATCH	=r11	; for use in interrupt routines
.def	rISCRATCH2	=r12	; ditto
.def	rISCRATCH3	=r13	; ditto
.def	rISCRATCH4	=r14	; ditto

.def	rISREGSAVE	=r15	; sreg saved here in interrupts

.def	rTEMP		=r16
.def	rTEMP2		=r17

.def	rITEMP		=r18	; for use in interrupt routines
.def	rITEMP2		=r19	; again, for use in interrupt routines

.def	rPARAM1		=r20	; parameter 1 for function calls
.def	rPARAM2		=r21	; parameter 2 for function calls

.def	rLOOPI		=r22	; loop counters
.def	rLOOPJ		=r23	; by tradition, I is outer loop, J inner

;-----------------------------------------------------------------
;
; Macros

; LDY	r,addr
.macro	LDY
	ldd @0,Y+(@1-RAMSTART)
.endmacro

; STY	addr,r
.macro	STY
	std Y+(@0-RAMSTART),@1
.endmacro

.listmac

; DEBUG	displayed_value

.macro	DEBUG
	push	rTEMP
	ldi	rTEMP,($FF-@0)
	out	PORTB,rTEMP
	pop	rTEMP
.endmacro

; DEBUG	displayed_register

.macro	DEBUGR
	push	rTEMP
	mov	rTEMP,@0
	com	rTEMP
	out	PORTB,rTEMP
	pop	rTEMP
.endmacro

;-----------------------------------------------------------------

.equ	ROBOT_CLOCKRATE	=4000000

;-----------------------------------------------------------------
